@@ -6,9 +6,8 @@ use crate::{
     util::idents_used_by,
 };
 use swc_atoms::js_word;
-use swc_common::{Spanned, DUMMY_SP};
+use swc_common::{util::take::Take, Spanned, DUMMY_SP};
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::ext::MapWithMut;
 use swc_ecma_utils::{ident::IdentLike, ExprExt, UsageFinder};
 
 /// Methods related to option `inline`.
