@@ -12,9 +12,8 @@ use crate::{
 use retain_mut::RetainMut;
 use std::mem::take;
 use swc_atoms::js_word;
-use swc_common::{Spanned, DUMMY_SP};
+use swc_common::{util::take::Take, Spanned, DUMMY_SP};
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::ext::MapWithMut;
 use swc_ecma_utils::{contains_this_expr, ident::IdentLike, undefined, ExprExt, Id, StmtLike};
 use swc_ecma_visit::{noop_visit_type, Node, Visit, VisitWith};
 
