@@ -1,8 +1,7 @@
 use super::Pure;
 use crate::mode::Mode;
-use swc_common::Spanned;
+use swc_common::{util::take::Take, Spanned};
 use swc_ecma_ast::*;
-use swc_ecma_transforms_base::ext::MapWithMut;
 use swc_ecma_utils::{ExprExt, Value};
 
 impl<M> Pure<'_, M>
